|PyPI version| |circle.ci builds|

Perf Django Agent
=================

``perf_agent`` is a middleware that will record timing and status codes
of the connections in the Django framework and send the data to Perf. We
then run analytics on that data to generate metrics and alerts.

Installation
------------

-  Easily install Perf via pip

.. code-block:: bash

   pip install django-perf

-  Add Perf configuration to your settings

.. code-block:: python
   
   PERF_CONFIG = {
      "api_key": "PERF_API_KEY"
   }

-  Add Perf to your list of Middleware classes

.. code-block:: python
   
   MIDDLEWARE_CLASSES = (
      'perf.middleware.PerfMiddleware',
      'django.middleware.common.CommonMiddleware',
      'django.middleware.csrf.CsrfViewMiddleware',
      ...
   )

.. |PyPI version| image:: https://badge.fury.io/py/django-perf.svg
   :target: https://badge.fury.io/py/django-perf
.. |circle.ci builds| image:: https://circleci.com/gh/perflabs/django-perf/tree/master.svg?style=shield&circle-token=21f056185e48e4d08cc62909f972ae235affacd8
   :target: https://circleci.com/gh/perflabs/django-perf
